# Contributors

Once you have added your contribution to `pyjanitor`,
please add your name using this markdown template:

```
[@githubname](https://github.com/githubname) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Agithubname)
```

You can copy/paste the template and replace `githubname` with your username.

Contributions that did not leave a commit trace
are indicated in bullet points below each user's username.

Leads
-----

- [@ericmjl](https://github.com/ericmjl) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Aericmjl)
- [@szuckerman](https://github.com/szuckerman) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Aszuckerman)
- [@zbarry](https://github.com/zbarry) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Azbarry)
    - Co-led sprint at SciPy 2019.
- [@hectormz](https://github.com/hectormz) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Ahectormz)
- [@jk3587](https://github.com/jk3587) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Ajk3587)
    - Tagged issues at SciPy 2019.
- [@sallyhong](https://github.com/sallyhong) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Asallyhong)
    - Tagged issues at SciPy 2019.
- [@zjpoh](https://github.com/zjpoh) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Azjpoh)
    - Started pyspark sub-module.
- [@anzelpwj](https://github.com/anzelpwj) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Aanzelpwj)
- [@samukweku](https://github.com/samukweku) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Asamukweku)
- [@loganthomas](https://github.com/loganthomas) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Aloganthomas)
    - Helped others with `git` issues at SciPy 2019.
- [@nvamsikrishna05](https://github.com/nvamsikrishna05) |  [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Anvamsikrishna05)


Contributors
------------

- [@JoshuaC3](https://github.com/JoshuaC3) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3AJoshuaC3)
- [@cduvallet](https://github.com/cduvallet) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Acduvallet)
- [@shantanuo](https://github.com/shantanuo) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Ashantanuo)
- [@jcvall](https://github.com/jcvall) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Ajcvall)
- [@CWen001](https://github.com/CWen001) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3ACWen001)
- [@bhallaY](https://github.com/bhallaY) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3AbhallaY)
- [@jekwatt](https://github.com/jekwatt) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Ajekwatt)
    - Helped other sprinters with `git` issues at SciPy 2019.
- [@kurtispinkney](https://github.com/kurtispinkney) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Akurtispinkney)
- [@lphk92](https://github.com/lphk92) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Alphk92)
- [@jonnybazookatone](https://github.com/jonnybazookatone) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Ajonnybazookatone)
- [@SorenFrohlich](https://github.com/SorenFrohlich) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3ASorenFrohlich)
- [@dave-frazzetto](https://github.com/dave-frazzetto) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Adave-frazzetto)
- [@dsouzadaniel](https://github.com/dsouzadaniel) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Adsouzadaniel)
- [@Eidhagen](https://github.com/Eidhagen) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3AEidhagen)
- [@mdini](https://github.com/mdini) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Amdini)
- [@kimt33](https://github.com/kimt33) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Akimt33)
- @jack-kessler-88 | user no longer found
- [@NapsterInBlue](https://github.com/NapsterInBlue) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3ANapsterInBlue)
- [@ricky-lim](https://github.com/ricky-lim) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Aricky-lim)
- [@catherinedevlin](https://github.com/catherinedevlin) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Acatherinedevlin)
- [@StephenSchroed](https://github.com/StephenSchroeder) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3AStephenSchroeder)
- [@Rajat-181](https://github.com/Rajat-181) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3ARajat-181)
- [@dendrondal](https://github.com/dendrondal) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Adendrondal)
- [@rahosbach](https://github.com/rahosbach) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Arahosbach)
- [@asearfos](https://github.com/asearfos) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Aasearfos)
- [@emnemnemnem](https://github.com/emnemnemnem) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Aemnemnemnem)
- [@rebeccawperry](https://github.com/rebeccawperry) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Arebeccawperry)
- [@TomMonks](https://github.com/TomMonks) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Atommonks)
- [@benjaminjack](https://github.com/benjaminjack) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Abenjaminjack)
- [@kulini](https://github.com/kulini) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Akulini)
- [@dwgoltra](https://github.com/dwgoltra) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Adwgoltra)
- [@shandou](https://github.com/shandou) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Ashandou)
- [@samwalkow](https://github.com/samwalkow) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Asamwalkow)
- [@portc13](https://github.com/portc13) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Aportc13)
- [@DSNortsev](https://github.com/DSNortsev) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3ADSNortsev)
- [@qtson](https://github.com/qtson) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Aqtson)
- [@keoghdata](https://github.com/keoghdata) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Akeoghdata)
- [@cjmayers](https://github.com/cjmayers) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Acjmayers)
- [@gjlynx](https://github.com/gjlynx) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Agjlynx)
- [@aopisco](https://github.com/aopisco) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Aaopisco)
- [@gaworecki5](https://github.com/gaworecki5) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Agaworecki5)
- [@puruckertom](https://github.com/puruckertom) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Apuruckertom)
- [@thomasjpfan](https://github.com/thomasjpfan) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Athomasjpfan)
- [@jiafengkevinchen](https://github.com/jiafengkevinchen) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Ajiafengkevinchen)
- [@mralbu](https://github.com/mralbu) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Amralbu)
- [@Ram-N](https://github.com/Ram-N) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3ARam-N)
- [@eyaltrabelsi](https://github.com/eyaltrabelsi) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Aeyaltrabelsi)
- [@gddcunh](https://github.com/gddcunh) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Agddcunh)
- [@DollofCuty](https://github.com/DollofCuty) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3ADollofCuty)
- [@bdice](https://github.com/bdice) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Abdice)
- [@evan-anderson](https://github.com/evan-anderson) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Aevan-anderson)
- [@smu095](https://github.com/smu095) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3smu095)
- [@VPerrollaz](https://github.com/VPerrollaz) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3AVPerrollaz)
- [@UGuntupalli](https://github.com/UGuntupalli) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3AUGuntupalli)
- [@mphirke](https://github.com/mphirke) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Amphirke)
- [@sauln](https://github.com/sauln) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Asauln)
- [@richardqiu](https://github.com/richardqiu) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Arichardqiu)
- [@MinchinWeb](https://github.com/MinchinWeb) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3AMinchinWeb)
- [@BaritoneBeard](https://github.com/BaritoneBeard) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3ABaritoneBeard)
- [@Sousa8697](https://github.com/Sousa8697) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3ASousa8697)
- [@MollyCroke](https://github.com/MollyCroke) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3AMollyCroke)
- [@ericclessantostv](https://github.com/ericlessantostv) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Aericclessantostv)
- [@fireddd](https://github.com/fireddd) |  [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Afireddd)
- [@Zeroto521](https://github.com/Zeroto521) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/pulls?utf8=%E2%9C%93&q=is%3Aclosed+mentions%3Zeroto521)
- [@thatlittleboy](https://github.com/thatlittleboy) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Athatlittleboy)
- [@robertmitchellv](https://github.com/robertmitchellv) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Arobertmitchellv)
- [@Econundrums](https://github.com/Econundrums) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3AEconundrums)
- [@ashenafiyb](https://github.com/ashenafiya) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Aashenafiyb)
- [@gahjelle](https://github.com/gahjelle) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Agahjelle)
- [@ethompsy](https://github.com/ethompsy) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Aethompsy)
- [@apatao](https://github.com/apatao) | [contributions](https://github.com/pyjanitor-devs/pyjanitor/issues?q=is%3Aclosed+mentions%3Aapatao)
